@@ -13,20 +13,20 @@ from sklearn.utils.fixes import delayed
 
 
 def cross_validate(
-        estimator,
-        X,
-        y=None,
-        *,
-        groups=None,
-        scoring=None,
-        cv=None,
-        n_jobs=None,
-        verbose=0,
-        fit_params=None,
-        pre_dispatch="2*n_jobs",
-        return_train_score=False,
-        return_estimator=False,
-        error_score=np.nan,
+    estimator,
+    views,
+    y=None,
+    *,
+    groups=None,
+    scoring=None,
+    cv=None,
+    n_jobs=None,
+    verbose=0,
+    fit_params=None,
+    pre_dispatch="2*n_jobs",
+    return_train_score=False,
+    return_estimator=False,
+    error_score=np.nan,
 ):
     """
     Evaluate metric(s) by cross-validation and also record fit/score times.
@@ -34,8 +34,7 @@ def cross_validate(
 
     :param estimator: estimator object implementing 'fit'
         The object to use to fit the data.
-    :param X: array-like of shape (n_samples, n_features)
-        The data to fit. Can be for example a list, or an array.
+    :param views: list/tuple of numpy arrays or array likes with the same number of rows (samples)
     :param y: array-like of shape (n_samples,) or (n_samples, n_outputs), default=None
         The target variable to try to predict in the case of
         supervised learning.
@@ -99,40 +98,42 @@ def cross_validate(
     """
     estimator = Pipeline(
         [
-            ("splitter", SimpleSplitter([X_.shape[1] for X_ in X])),
+            ("splitter", SimpleSplitter([X_.shape[1] for X_ in views])),
             ("estimator", clone(estimator)),
         ]
     )
-    ret = cross_validate_(estimator,
-                          np.hstack(X),
-                          y=y,
-                          groups=groups,
-                          scoring=scoring,
-                          cv=cv,
-                          n_jobs=n_jobs,
-                          verbose=verbose,
-                          fit_params=fit_params,
-                          pre_dispatch=pre_dispatch,
-                          return_train_score=return_train_score,
-                          return_estimator=return_estimator,
-                          error_score=error_score)
+    ret = cross_validate_(
+        estimator,
+        np.hstack(views),
+        y=y,
+        groups=groups,
+        scoring=scoring,
+        cv=cv,
+        n_jobs=n_jobs,
+        verbose=verbose,
+        fit_params=fit_params,
+        pre_dispatch=pre_dispatch,
+        return_train_score=return_train_score,
+        return_estimator=return_estimator,
+        error_score=error_score,
+    )
     if return_estimator:
-        ret['estimator'] = [estimator['estimator'] for estimator in ret['estimator']]
+        ret["estimator"] = [estimator["estimator"] for estimator in ret["estimator"]]
     return ret
 
 
 def permutation_test_score(
-        estimator,
-        X,
-        y=None,
-        groups=None,
-        cv=None,
-        n_permutations=100,
-        n_jobs=None,
-        random_state=0,
-        verbose=0,
-        scoring=None,
-        fit_params=None,
+    estimator,
+    views,
+    y=None,
+    groups=None,
+    cv=None,
+    n_permutations=100,
+    n_jobs=None,
+    random_state=0,
+    verbose=0,
+    scoring=None,
+    fit_params=None,
 ):
     """
     Evaluate the significance of a cross-validated score with permutations
@@ -150,8 +151,7 @@ def permutation_test_score(
 
     :param estimator: estimator object implementing 'fit'
         The object to use to fit the data.
-    :param X: array-like of shape at least 2D
-        The data to fit.
+    :param views: list/tuple of numpy arrays or array likes with the same number of rows (samples)
     :param y: array-like of shape (n_samples,) or (n_samples, n_outputs) or None
         The target variable to try to predict in the case of
         supervised learning.
@@ -202,11 +202,11 @@ def permutation_test_score(
     """
     estimator = Pipeline(
         [
-            ("splitter", SimpleSplitter([X_.shape[1] for X_ in X])),
+            ("splitter", SimpleSplitter([X_.shape[1] for X_ in views])),
             ("estimator", clone(estimator)),
         ]
     )
-    X, y, groups = indexable(np.hstack(X), y, groups)
+    views, y, groups = indexable(np.hstack(views), y, groups)
 
     cv = check_cv(cv, y, classifier=is_classifier(estimator))
     scorer = check_scoring(estimator, scoring=scoring)
@@ -215,12 +215,12 @@ def permutation_test_score(
     # We clone the estimator to make sure that all the folds are
     # independent, and that it is pickle-able.
     score = _permutation_test_score(
-        clone(estimator), X, y, groups, cv, scorer, fit_params=fit_params
+        clone(estimator), views, y, groups, cv, scorer, fit_params=fit_params
     )
     permutation_scores = Parallel(n_jobs=n_jobs, verbose=verbose)(
         delayed(_permutation_test_score)(
             clone(estimator),
-            _shuffle(X, groups, random_state, estimator['splitter']),
+            _shuffle(views, groups, random_state, estimator["splitter"]),
             y,
             groups,
             cv,
@@ -250,22 +250,22 @@ def _shuffle(X, groups, random_state, splitter):
 
 
 def learning_curve(
-        estimator,
-        X,
-        y=None,
-        groups=None,
-        train_sizes=np.linspace(0.1, 1.0, 5),
-        cv=None,
-        scoring=None,
-        exploit_incremental_learning=False,
-        n_jobs=None,
-        pre_dispatch="all",
-        verbose=0,
-        shuffle=False,
-        random_state=None,
-        error_score=np.nan,
-        return_times=False,
-        fit_params=None,
+    estimator,
+    views,
+    y=None,
+    groups=None,
+    train_sizes=np.linspace(0.1, 1.0, 5),
+    cv=None,
+    scoring=None,
+    exploit_incremental_learning=False,
+    n_jobs=None,
+    pre_dispatch="all",
+    verbose=0,
+    shuffle=False,
+    random_state=None,
+    error_score=np.nan,
+    return_times=False,
+    fit_params=None,
 ):
     """
     Learning curve.
@@ -280,11 +280,9 @@ def learning_curve(
 
     :param estimator: object type that implements the "fit" and "predict" methods
         An object of that type which is cloned for each validation.
-    :param X: array-like of shape (n_samples, n_features)
-        Training vector, where `n_samples` is the number of samples and
-        `n_features` is the number of features.
+    :param views: list/tuple of numpy arrays or array likes with the same number of rows (samples)
     :param y: array-like of shape (n_samples,) or (n_samples, n_outputs)
-        Target relative to X for classification or regression;
+        Target relative to views for classification or regression;
         None for unsupervised learning.
     :param groups: array-like of  shape (n_samples,), default=None
         Group labels for the samples used while splitting the dataset into
@@ -317,7 +315,7 @@ def learning_curve(
     :param scoring: str or callable, default=None
         A str (see model evaluation documentation) or
         a scorer callable object / function with signature
-        ``scorer(estimator, X, y)``.
+        ``scorer(estimator, views, y)``.
     :param exploit_incremental_learning: bool, default=False
         If the estimator supports incremental learning, this will be
         used to speed up fitting for different training set sizes.
@@ -354,13 +352,13 @@ def learning_curve(
     """
     estimator = Pipeline(
         [
-            ("splitter", SimpleSplitter([X_.shape[1] for X_ in X])),
+            ("splitter", SimpleSplitter([X_.shape[1] for X_ in views])),
             ("estimator", clone(estimator)),
         ]
     )
     return learning_curve_(
         estimator,
-        np.hstack(X),
+        np.hstack(views),
         y,
         groups=groups,
         train_sizes=train_sizes,
