@@ -7,12 +7,11 @@ This example demonstrates multiview models which can reconstruct their inputs
 import matplotlib.pyplot as plt
 import pytorch_lightning as pl
 
-from cca_zoo.deepmodels import _architectures, DCCAE, DVCCA, SplitAE
-from cca_zoo.utils import tsne_label
+from cca_zoo.deepmodels import architectures, DCCAE, DVCCA, SplitAE
+from cca_zoo.plotting import tsne_label
 from examples import example_mnist_data
 
 
-# %%
 def plot_reconstruction(model, x, uncertainty=False):
     recons = model.recon(x["views"], mle=True)
     n_cols = 2 + uncertainty
@@ -27,6 +26,9 @@ def plot_reconstruction(model, x, uncertainty=False):
         ax[2].imshow(uncertainty_recons[0].detach().numpy().reshape((28, 28)))
 
 
+# %%
+# Data
+# -----
 LATENT_DIMS = 2
 EPOCHS = 10
 N_TRAIN = 500
@@ -39,19 +41,21 @@ train_loader, val_loader, train_labels = example_mnist_data(
     N_TRAIN, N_VAL, type="noisy"
 )
 
+
 # %%
 # Deep Variational CCA
-encoder_1 = _architectures.Encoder(
+# ----------------------------
+encoder_1 = architectures.Encoder(
     latent_dims=LATENT_DIMS,
     feature_size=784,
     variational=True,
     layer_sizes=layer_sizes,
     dropout=dropout,
 )
-decoder_1 = _architectures.Decoder(
+decoder_1 = architectures.Decoder(
     latent_dims=LATENT_DIMS, feature_size=784, layer_sizes=layer_sizes, dropout=dropout
 )
-decoder_2 = _architectures.Decoder(
+decoder_2 = architectures.Decoder(
     latent_dims=LATENT_DIMS, feature_size=784, layer_sizes=layer_sizes, dropout=dropout
 )
 dvcca = DVCCA(
@@ -72,29 +76,31 @@ plot_reconstruction(dvcca, train_loader.dataset[0], uncertainty=True)
 plt.suptitle("DVCCA")
 plt.show()
 
+
 # %%
-# Deep Variational CCA Private
-private_encoder_1 = _architectures.Encoder(
+# Deep Variational CCA (Private)
+# -------------------------------
+private_encoder_1 = architectures.Encoder(
     latent_dims=LATENT_DIMS,
     feature_size=784,
     variational=True,
     layer_sizes=layer_sizes,
     dropout=dropout,
 )
-private_encoder_2 = _architectures.Encoder(
+private_encoder_2 = architectures.Encoder(
     latent_dims=LATENT_DIMS,
     feature_size=784,
     variational=True,
     layer_sizes=layer_sizes,
     dropout=dropout,
 )
-private_decoder_1 = _architectures.Decoder(
+private_decoder_1 = architectures.Decoder(
     latent_dims=2 * LATENT_DIMS,
     feature_size=784,
     layer_sizes=layer_sizes,
     dropout=dropout,
 )
-private_decoder_2 = _architectures.Decoder(
+private_decoder_2 = architectures.Decoder(
     latent_dims=2 * LATENT_DIMS,
     feature_size=784,
     layer_sizes=layer_sizes,
@@ -119,18 +125,20 @@ plot_reconstruction(dvccap, train_loader.dataset[0], uncertainty=True)
 plt.suptitle("DVCCA Private")
 plt.show()
 
+
 # %%
 # Deep Canonically Correlated Autoencoders
-encoder_1 = _architectures.Encoder(
+# -----------------------------------------
+encoder_1 = architectures.Encoder(
     latent_dims=LATENT_DIMS, feature_size=784, layer_sizes=layer_sizes
 )
-encoder_2 = _architectures.Encoder(
+encoder_2 = architectures.Encoder(
     latent_dims=LATENT_DIMS, feature_size=784, layer_sizes=layer_sizes
 )
-decoder_1 = _architectures.Decoder(
+decoder_1 = architectures.Decoder(
     latent_dims=LATENT_DIMS, feature_size=784, layer_sizes=layer_sizes, dropout=dropout
 )
-decoder_2 = _architectures.Decoder(
+decoder_2 = architectures.Decoder(
     latent_dims=LATENT_DIMS, feature_size=784, layer_sizes=layer_sizes, dropout=dropout
 )
 dccae = DCCAE(
@@ -153,15 +161,17 @@ plot_reconstruction(dccae, train_loader.dataset[0])
 plt.suptitle("DCCAE")
 plt.show()
 
+
 # %%
 # Split Autoencoders
-encoder_1 = _architectures.Encoder(
+# -------------------
+encoder_1 = architectures.Encoder(
     latent_dims=LATENT_DIMS, feature_size=784, layer_sizes=layer_sizes
 )
-decoder_1 = _architectures.Decoder(
+decoder_1 = architectures.Decoder(
     latent_dims=LATENT_DIMS, feature_size=784, layer_sizes=layer_sizes, dropout=dropout
 )
-decoder_2 = _architectures.Decoder(
+decoder_2 = architectures.Decoder(
     latent_dims=LATENT_DIMS, feature_size=784, layer_sizes=layer_sizes, dropout=dropout
 )
 splitae = SplitAE(
