@@ -4,12 +4,15 @@ More than 2 views
 
 This will compare MCCA, GCCA, TCCA for linear models with more than 2 views
 """
-# %%
 import numpy as np
 
 from cca_zoo.data import generate_covariance_data
 from cca_zoo.models import MCCA, GCCA, TCCA, KCCA, KGCCA, KTCCA, SCCA_PMD
 
+"""
+Data
+-----
+"""
 # %%
 np.random.seed(42)
 n = 30
@@ -25,7 +28,11 @@ cv = 3
 
 # %%
 # Eigendecomposition-Based Methods
-# ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+# ---------------------------------
+
+# %%
+# Linear
+# ^^^^^^^^
 
 # %%
 mcca = MCCA(latent_dims=latent_dims).fit((X, Y, X)).score((X, Y, Z))
@@ -34,8 +41,8 @@ mcca = MCCA(latent_dims=latent_dims).fit((X, Y, X)).score((X, Y, Z))
 gcca = GCCA(latent_dims=latent_dims).fit((X, Y, X)).score((X, Y, Z))
 
 # %%
-# We can also use kernel versions of these methods
-# ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+# Kernel
+# ^^^^^^^^
 
 # %%
 kcca = KCCA(latent_dims=latent_dims).fit((X, Y, X)).score((X, Y, Z))
@@ -44,9 +51,17 @@ kcca = KCCA(latent_dims=latent_dims).fit((X, Y, X)).score((X, Y, Z))
 kgcca = KGCCA(latent_dims=latent_dims).fit((X, Y, X)).score((X, Y, Z))
 
 # %%
-# Higher order correlation methods
-# ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+# Iterative Methods
+# ^^^^^^^^^^^^^^^^^^
 
+# Most of the _iterative methods can also use multiple views e.g.
+
+pmd = SCCA_PMD(latent_dims=latent_dims, c=1).fit((X, Y, X)).score((X, Y, Z))
+
+
+# %%
+# Higher Order Correlations
+# -------------------------
 
 # %%
 # Tensor CCA finds higher order correlations so scores are not comparable (but TCCA is equivalent for 2 views)
@@ -54,11 +69,3 @@ tcca = TCCA(latent_dims=latent_dims).fit((X, Y, X)).score((X, Y, Z))
 
 # %%
 ktcca = KTCCA(latent_dims=latent_dims).fit((X, Y, X)).score((X, Y, Z))
-
-# %%
-# Iterative Methods
-# ^^^^^^^^^^^^^^^^^^^^^^
-#
-# Most of the _iterative methods can also use multiple views e.g.
-
-pmd = SCCA_PMD(latent_dims=latent_dims, c=1).fit((X, Y, X)).score((X, Y, Z))
